@@ -23,39 +23,56 @@ class PubMedArticle(MetaPubObject):
 
     def __init__(self, xmlstr, *args, **kwargs):
         super(PubMedArticle, self).__init__(xmlstr, 'PubmedArticle', args, kwargs)
+        self.pmid = self._get_pmid()
+        self.abstract = self._get_abstract()
+        self.authors = self._get_authors()
+        self.authors_str = self._get_authors_str()
+        self.author1_last_fm = self._get_author1_last_fm()        
+        self.author1_lastfm = self._get_author1_lastfm()
+        self.title = self._get_title()
+        self.journal = self._get_journal()
+        self.pages = self._get_pages()
+        self.first_page = self._get_first_page()
+        self.last_page = self._get_last_page()
+        self.volume = self._get_volume()
+        self.issue = self._get_issue()
+        self.volume_issue = self._get_volume_issue()
+        self.year = self._get_year()
+        self.doi = self._get_doi()
+        self.pii = self._get_pii()
+        self.pmc = self._get_pmc()
 
-    @property
-    def pmid(self):
+    def to_dict(self):
+        outd = self.__dict__
+        outd.pop('content')
+        outd.pop('xmlstr')
+        return self.__dict__
+
+    def _get_pmid(self):
         return self._get('MedlineCitation/PMID')
 
-    @property
-    def abstract(self):
+    def _get_abstract(self):
         return self._get('MedlineCitation/Article/Abstract/AbstractText')
 
-    @property
-    # N.B. Citations may have 0 authors. e.g., pmid:7550356
-    def authors(self):
+    def _get_authors(self):
+        # N.B. Citations may have 0 authors. e.g., pmid:7550356
         authors = [ _au_to_last_fm(au) for au in self.content.findall('MedlineCitation/Article/AuthorList/Author') ]
         return authors
 
-    @property
-    def authors_str(self):
+    def _get_authors_str(self):
         return '; '.join(self.authors) 
 
-    @property
-    def author1_last_fm(self):
-        """return first author's name, in format Last INITS (space between surname and inits)"""
+    def _get_author1_last_fm(self):
+        '''return first author's name, in format Last INITS (space between surname and inits)'''
         return _au_to_last_fm(self.content.find('MedlineCitation/Article/AuthorList/Author'))
 
-    @property
-    def author1_lastfm(self):
-        """return first author's name, in format LastINITS"""
+    def _get_author1_lastfm(self):
+        '''return first author's name, in format LastINITS'''
         if self.author1_last_fm is not None:
             return self.author1_last_fm.replace(' ','')
         return None
 
-    @property
-    def journal(self):
+    def _get_journal(self):
         j = self._get('MedlineCitation/Article/Journal/ISOAbbreviation')
         if j is None:
             # e.g., http://www.ncbi.nlm.nih.gov/pubmed?term=21242195
@@ -63,44 +80,44 @@ class PubMedArticle(MetaPubObject):
         assert j is not None
         return j
 
-    @property
-    def pages(self):
+    def _get_pages(self):
         return self._get('MedlineCitation/Article/Pagination/MedlinePgn') 
 
-    @property
-    def first_page(self):
+    def _get_first_page(self):
         try:
-            return self.pages.partition('-')[0]
+            return self.pages.split('-')[0]
         except AttributeError:
             return self.pages
 
-    @property
-    def last_page(self):
+    def _get_last_page(self):
         try:
-            return self.pages.partition('-')[1]
+            lastnum = self.pages.split('-')[1]
+            return lastnum
+            
+            #TODO: return true last page in situations like self.pages = "148-52"
+            #           i.e. we want last_page = "152", not "52"
+            #if lastnum < self.first_page:
+            #    len(lastnum)....
+
         except AttributeError:
             return None
 
-    @property
-    def title(self):
+    def _get_title(self):
         return self._get('MedlineCitation/Article/ArticleTitle') 
 
-    @property
-    def volume(self):
+    def _get_volume(self):
         try:
             return self.content.find('MedlineCitation/Article/Journal/JournalIssue/Volume').text
         except AttributeError:
             return None
 
-    @property
-    def issue(self):
+    def _get_issue(self):
         try:
             return self.content.find('MedlineCitation/Article/Journal/JournalIssue/Issue').text
         except AttributeError:
             return None
 
-    @property
-    def volume_issue(self):
+    def _get_volume_issue(self):
         ji = self.content.find('MedlineCitation/Article/Journal/JournalIssue')
         try:
             return '%s(%s)' % (ji.find('Volume').text, ji.find('Issue').text)
@@ -116,8 +133,7 @@ class PubMedArticle(MetaPubObject):
         logger.info("No volume for "+self.pmid)
         return None
 
-    @property
-    def year(self):
+    def _get_year(self):
         y = self._get('MedlineCitation/Article/Journal/JournalIssue/PubDate/Year')
         if y is None:
             # case applicable for pmid:9887384 (at least)
@@ -125,16 +141,13 @@ class PubMedArticle(MetaPubObject):
         assert y is not None
         return y
 
-    @property
-    def doi(self):
+    def _get_doi(self):
         return self._get('PubmedData/ArticleIdList/ArticleId[@IdType="doi"]')
 
-    @property
-    def pii(self):
+    def _get_pii(self):
         return self._get('PubmedData/ArticleIdList/ArticleId[@IdType="pii"]')
 
-    @property
-    def pmc(self):
+    def _get_pmc(self):
         try:
             return self._get('PubmedData/ArticleIdList/ArticleId[@IdType="pmc"]')[3:]
         except TypeError:
